==> idoit-analytics-1.1.2.zip: src/classes/modules/analytics/lang/en.inc.php <==
<?php
/**
 * i-doit
 *
 * "Analytics" Module language file
 *
 * @package     modules
 * @subpackage  analytics
 * @author      Leonard Fischer <lfischer@i-doit.com>
 * @version     1.0.5
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.3
 */

return [
    'LC__MODULE__ANALYTICS'                                                    => 'Analytics',
    'LC__MODULE__ANALYTICS__SELECT'                                            => 'Select',
    'LC__MODULE__ANALYTICS__FILTERS'                                           => 'Servicefilter',
    'LC__MODULE__ANALYTICS__RESULT_FILTER'                                     => 'Result filter',
    'LC__MODULE__ANALYTICS__RESULT_FILTER_DESCRIPTION'                         => 'The result filter can be used to filter the displayed loaded data (see servicefilter). Currently only object types and levels can be filtered.',
    'LC__MODULE__ANALYTICS__RESULT_FILTER__SWITCH_ON'                          => 'Activate',
    'LC__MODULE__ANALYTICS__RESULT_FILTER__SWITCH_OFF'                         => 'Deactivate',
    'LC__MODULE__ANALYTICS__ITSERVICE'                                         => 'Service',
    'LC__MODULE__ANALYTICS__IMPACT_WEIGHTING'                                  => 'Impact weighting',
    'LC__MODULE__ANALYTICS__FILTERS_DESCRIPTION'                               => 'Here you can select a previously defined filter. If you wish to create a new one, simply click <a href="%s">here</a>!',
    'LC__MODULE__ANALYTICS__RESULT'                                            => 'Result',
    'LC__MODULE__ANALYTICS__SIMULATION__START'                                 => 'Start the simulation',
    'LC__MODULE__ANALYTICS__SIMULATION__PRIORITY'                              => 'Priority',
    'LC__MODULE__ANALYTICS__SIMULATION__AFFECTED_RELATIONS'                    => 'Affected relations',
    'LC__MODULE__ANALYTICS__SIMULATION__JS_LIST_RECURSION_WARNING'             => 'Due to the data load a more simple list will be displayed',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST'                             => 'Tree view',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST_ROOT'                        => 'Root',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST_OPEN_ALL'                    => 'Open tree',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST_TOGGLE_OBJECTS'              => 'Open up the list to the simulation objects',
    'LC__MODULE__ANALYTICS__SIMULATION__CMDB_EXPLORER'                         => 'CMDB-explorer',
    'LC__MODULE__ANALYTICS__SIMULATION__CMDB_EXPLORER_LOAD'                    => 'Load the CMDB-explorer',
    'LC__MODULE__ANALYTICS__SIMULATION__NO_OBJECTS_FOUND'                      => 'No objects could be found...',
    'LC__MODULE__ANALYTICS__SIMULATION__NO_OBJECTS_FOUND_IN_REPORT'            => 'No objects could be found. The selected report needs to include the object ID in the field "__id__".',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION'                                   => 'Impact simulation',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__OBJECT_LABEL'                     => 'Object selection',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__OBJECT_SELECTION'                 => 'Select "simulation objects" which shall be used in the simulation.',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__MANUAL_SELECTION'                 => 'Manual selection',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__REPORT_SELECTION'                 => 'Selection by report',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__DISPLAY_VIEWTYPE'                 => 'Viewtype',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__IT_SERVICES_ONLY'                 => 'Only display the direct path to the it services in the treeview',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__MONITORING_SELECTION'             => 'Live selection (Monitoring)',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__REPORT_SELECTION_DESCRIPTION'     => 'Select one of your reports and click the "Load" button to use the resulting objects as simulation objects',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__MONITORING_SELECTION_DESCRIPTION' => 'Select one of your configured monitoring instances and click "Load"',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__NO_MONITORING_INSTANCE'           => 'It seems as if your installation does not provide any monitoring instances',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__NO_REPORTS'                       => 'It seems as if your installation does not provide any reports',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__LOAD_IMPACT_OBJECTS'              => 'Load simulation object(s)',
    'LC__MODULE__ANALYTICS__AUTH__SIMULATION'                                  => 'Analytics',
    'LC__MODULE__ANALYTICS__AUTH__SIMULATION_EXCEPTION'                        => 'You are not allowed to view this simulation.',
    'LC__MODULE__ANALYTICS__AUTH__DATAQUALITY_PROFILES'                        => 'Manage the dataquality profiles',
    'LC__MODULE__ANALYTICS__AUTH__DATAQUALITY_PROFILES_EXCEPTION'              => 'You are not allowed to edit the profile!',
    'LC__MODULE__ANALYTICS__LIVE_IMPACT'                                       => 'Impact live',
    'LC__MODULE__ANALYTICS__LIVE_IMPACT__START'                                => 'Load affected services',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG'                                    => 'Objectcatalog',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__LOAD_OBJECT_DATA'                  => 'Load object data',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__OBJ_COUNT'                         => 'Amount of objects',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FIELD_KEY'                         => 'Field name',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FIELD_VALUE'                       => 'Field value(s)',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__SERVICE_OBJ'                       => 'Service and attribute selection',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__OBJECT_SELECTION'                  => 'Select a service to load the objects and additional data underneath it.',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FOUND_0_OBJECTS'                   => 'No objects could be found!',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FOUND_X_OBJECTS'                   => '%d objects were found! Now we will load the associated attributes...',
    'LC__MODULE__ANALYTICS__DATA_QUALITY'                                      => 'Data quality',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__CALCULATED_QUALITY'                  => 'Data quality',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__SHOW_DETAIL_DATA'                    => 'Show detailed information',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__HIDE_DETAIL_DATA'                    => 'Hide detailed information',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__OF_X_CATEGORIES'                     => 'inside {x} categories',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESET_CATEGORIES'                    => 'Reset',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESET_CATEGORIES_DESCRIPTION'        => 'By clicking this button the prior hidden categories will be displayed again',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__CATEGORY_CONTENT'                    => 'Entry',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__CATEGORY_CONTENTS'                   => 'Entries',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESET_VIEW'                          => 'Reset object types',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__REMOVE_OBJECTTYPE'                   => 'Hides this object type from the view',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__REMOVE_CATEGORY'                     => 'Hides this category from the view',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__SAVE_AS_NEW_PROFILE'                 => 'Save as new profile',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__USER_SPECIFIC'                       => 'User specific',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__TITLE_IS_MISSING'                    => 'Please enter a title',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__MAKE_PUBLIC'                         => 'Publish your profile for others',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__MAKE_PUBLIC_CONFIRM'                 => 'Are you sure you want to publish this profile?',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__MAKE_PUBLIC_NOTIFY'                  => 'Your profile is now available for all users!',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__PURGE'                               => 'Delete profile',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__PURGE_CONFIRM'                       => 'Are you sure you want to delete this profile?',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__ABORT_REQUEST_INFO'                  => 'The request has been aborted!',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__SHOW_RESPONSIBLE_OBJECTS'            => 'Display objects without data',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESPONSIBLE_OBJECTS_HEADLINE'        => 'Table with Objects, whose "<span></span>" category is empty (limited to 100)',
    'LC__MODULE__ANALYTICS__SERVICECOSTS'                                      => 'Servicecosts',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CALCULATE'                           => 'Calculate servicecosts',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__LICENCE_COSTS'                       => 'Licence costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__OVERVIEW'                            => 'Cost overview',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__MISC_OVERVIEW'                       => 'Miscellaneous overview',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__DOCUMENTED_COSTS'                    => 'Documented costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__DOCUMENTED_VALUES'                   => 'Documented values',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CHART_MONEY_UNIT_DESCRIPTION'        => '* All values in %s',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__SUMMED'                              => 'Summed up',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__LICENCECOST'                         => 'Licence costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CONTRACTCOST'                        => 'Contract costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CONTRACTCOST__ALREADY_CALCULATED'    => 'Once overall',
    'LC__MODULE__ANALYTICS__NOTIFY__EMPTY_ATTRIBUTE_RESULT'                    => 'To load the attributes the system needs at least one object.',
    'LC__MODULE__ANALYTICS__NOTIFY__CAT_CONST_NOT_FOUND'                       => 'The given category constant "%s" could not be found.',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_IMPACT_OBJECT'                          => 'You have selected no impact object!',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_ATTRIBUTES'                             => 'You have selected no attributes!',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_JSON_RESPONSE'                          => 'The function "%s" did not answer with proper JSON Data, please check the i-doit LOG.',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_OBJECTS_FOR_GIVEN_TYPE'                 => 'The given objecttype "%s" has no objects.',
    'LC__MODULE__ANALYTICS__EXCEPTION__NO_CLASS_FOUND'                         => 'The given class "%s" could not be found!',
    'LC__MODULE__ANALYTICS__EXCEPTION__NO_REPORT_FOUND'                        => 'The given report "%s" could not be found!',
    'LC__MODULE__ANALYTICS__EXCEPTION__FILTER_NAME_UNIQUE'                     => 'Attention! The filtername needs to be unique, please choose another title.',
];

==> idoit-analytics-1.1.3.zip: src/classes/modules/analytics/lang/en.inc.php <==
<?php
/**
 * i-doit
 *
 * "Analytics" Module language file
 *
 * @package     modules
 * @subpackage  analytics
 * @author      Leonard Fischer <lfischer@i-doit.com>
 * @version     1.0.5
 * @copyright   synetics GmbH
 * @license     http://www.i-doit.com/license
 * @since       i-doit 1.4.3
 */

return [
    'LC__MODULE__ANALYTICS'                                                    => 'Analytics',
    'LC__MODULE__ANALYTICS__SELECT'                                            => 'Select',
    'LC__MODULE__ANALYTICS__FILTERS'                                           => 'Servicefilter',
    'LC__MODULE__ANALYTICS__RESULT_FILTER'                                     => 'Result filter',
    'LC__MODULE__ANALYTICS__RESULT_FILTER_DESCRIPTION'                         => 'The result filter can be used to filter the displayed loaded data (see servicefilter). Currently only object types and levels can be filtered.',
    'LC__MODULE__ANALYTICS__RESULT_FILTER__SWITCH_ON'                          => 'Activate',
    'LC__MODULE__ANALYTICS__RESULT_FILTER__SWITCH_OFF'                         => 'Deactivate',
    'LC__MODULE__ANALYTICS__ITSERVICE'                                         => 'Service',
    'LC__MODULE__ANALYTICS__IMPACT_WEIGHTING'                                  => 'Impact weighting',
    'LC__MODULE__ANALYTICS__FILTERS_DESCRIPTION'                               => 'Here you can select a previously defined filter. If you wish to create a new one, simply click <a href="%s">here</a>!',
    'LC__MODULE__ANALYTICS__RESULT'                                            => 'Result',
    'LC__MODULE__ANALYTICS__SIMULATION__START'                                 => 'Start the simulation',
    'LC__MODULE__ANALYTICS__SIMULATION__PRIORITY'                              => 'Priority',
    'LC__MODULE__ANALYTICS__SIMULATION__AFFECTED_RELATIONS'                    => 'Affected relations',
    'LC__MODULE__ANALYTICS__SIMULATION__JS_LIST_RECURSION_WARNING'             => 'Due to the data load a more simple list will be displayed',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST'                             => 'Tree view',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST_ROOT'                        => 'Root',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST_OPEN_ALL'                    => 'Open tree',
    'LC__MODULE__ANALYTICS__SIMULATION__HTML_LIST_TOGGLE_OBJECTS'              => 'Open up the list to the simulation objects',
    'LC__MODULE__ANALYTICS__SIMULATION__CMDB_EXPLORER'                         => 'CMDB-explorer',
    'LC__MODULE__ANALYTICS__SIMULATION__CMDB_EXPLORER_LOAD'                    => 'Load the CMDB-explorer',
    'LC__MODULE__ANALYTICS__SIMULATION__NO_OBJECTS_FOUND'                      => 'No objects could be found...',
    'LC__MODULE__ANALYTICS__SIMULATION__NO_OBJECTS_FOUND_IN_REPORT'            => 'No objects could be found. The selected report needs to include the object ID in the field "__id__".',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION'                                   => 'Impact simulation',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__OBJECT_LABEL'                     => 'Object selection',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__OBJECT_SELECTION'                 => 'Select "simulation objects" which shall be used in the simulation.',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__MANUAL_SELECTION'                 => 'Manual selection',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__REPORT_SELECTION'                 => 'Selection by report',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__DISPLAY_VIEWTYPE'                 => 'Viewtype',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__IT_SERVICES_ONLY'                 => 'Only display the direct path to the it services in the treeview',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__MONITORING_SELECTION'             => 'Live selection (Monitoring)',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__REPORT_SELECTION_DESCRIPTION'     => 'Select one of your reports and click the "Load" button to use the resulting objects as simulation objects',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__MONITORING_SELECTION_DESCRIPTION' => 'Select one of your configured monitoring instances and click "Load"',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__NO_MONITORING_INSTANCE'           => 'It seems as if your installation does not provide any monitoring instances',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__NO_REPORTS'                       => 'It seems as if your installation does not provide any reports',
    'LC__MODULE__ANALYTICS__FAIL_SIMULATION__LOAD_IMPACT_OBJECTS'              => 'Load simulation object(s)',
    'LC__MODULE__ANALYTICS__AUTH__SIMULATION'                                  => 'Analytics',
    'LC__MODULE__ANALYTICS__AUTH__SIMULATION_EXCEPTION'                        => 'You are not allowed to view this simulation.',
    'LC__MODULE__ANALYTICS__AUTH__DATAQUALITY_PROFILES'                        => 'Manage the dataquality profiles',
    'LC__MODULE__ANALYTICS__AUTH__DATAQUALITY_PROFILES_EXCEPTION'              => 'You are not allowed to edit the profile!',
    'LC__MODULE__ANALYTICS__LIVE_IMPACT'                                       => 'Impact live',
    'LC__MODULE__ANALYTICS__LIVE_IMPACT__START'                                => 'Load affected services',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG'                                    => 'Objectcatalog',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__LOAD_OBJECT_DATA'                  => 'Load object data',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__OBJ_COUNT'                         => 'Amount of objects',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FIELD_KEY'                         => 'Field name',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FIELD_VALUE'                       => 'Field value(s)',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__SERVICE_OBJ'                       => 'Service and attribute selection',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__OBJECT_SELECTION'                  => 'Select a service to load the objects and additional data underneath it.',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FOUND_0_OBJECTS'                   => 'No objects could be found!',
    'LC__MODULE__ANALYTICS__OBJECT_CATALOG__FOUND_X_OBJECTS'                   => '%d objects were found! Now we will load the associated attributes...',
    'LC__MODULE__ANALYTICS__DATA_QUALITY'                                      => 'Data quality',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__CALCULATED_QUALITY'                  => 'Data quality',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__SHOW_DETAIL_DATA'                    => 'Show detailed information',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__HIDE_DETAIL_DATA'                    => 'Hide detailed information',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__OF_X_CATEGORIES'                     => 'inside {x} categories',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESET_CATEGORIES'                    => 'Reset',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESET_CATEGORIES_DESCRIPTION'        => 'By clicking this button the prior hidden categories will be displayed again',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__CATEGORY_CONTENT'                    => 'Entry',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__CATEGORY_CONTENTS'                   => 'Entries',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESET_VIEW'                          => 'Reset object types',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__REMOVE_OBJECTTYPE'                   => 'Hides this object type from the view',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__REMOVE_CATEGORY'                     => 'Hides this category from the view',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__SAVE_AS_NEW_PROFILE'                 => 'Save as new profile',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__USER_SPECIFIC'                       => 'User specific',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__TITLE_IS_MISSING'                    => 'Please enter a title',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__MAKE_PUBLIC'                         => 'Publish your profile for others',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__MAKE_PUBLIC_CONFIRM'                 => 'Are you sure you want to publish this profile?',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__MAKE_PUBLIC_NOTIFY'                  => 'Your profile is now available for all users!',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__PURGE'                               => 'Delete profile',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__PURGE_CONFIRM'                       => 'Are you sure you want to delete this profile?',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__ABORT_REQUEST_INFO'                  => 'The request has been aborted!',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__SHOW_RESPONSIBLE_OBJECTS'            => 'Display objects without data',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__RESPONSIBLE_OBJECTS_HEADLINE'        => 'Table with Objects, whose "<span></span>" category is empty (limited to 100)',
    'LC__MODULE__ANALYTICS__DATA_QUALITY__OBJECT_TYPE_WITHOUT_CATEGORIES'      => 'Attention! The object type "%s" does not have any assigned categories.',
    'LC__MODULE__ANALYTICS__SERVICECOSTS'                                      => 'Servicecosts',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CALCULATE'                           => 'Calculate servicecosts',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__LICENCE_COSTS'                       => 'Licence costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__OVERVIEW'                            => 'Cost overview',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__MISC_OVERVIEW'                       => 'Miscellaneous overview',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__DOCUMENTED_COSTS'                    => 'Documented costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__DOCUMENTED_VALUES'                   => 'Documented values',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CHART_MONEY_UNIT_DESCRIPTION'        => '* All values in %s',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__SUMMED'                              => 'Summed up',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__LICENCECOST'                         => 'Licence costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CONTRACTCOST'                        => 'Contract costs',
    'LC__MODULE__ANALYTICS__SERVICECOSTS__CONTRACTCOST__ALREADY_CALCULATED'    => 'Once overall',
    'LC__MODULE__ANALYTICS__NOTIFY__EMPTY_ATTRIBUTE_RESULT'                    => 'To load the attributes the system needs at least one object.',
    'LC__MODULE__ANALYTICS__NOTIFY__CAT_CONST_NOT_FOUND'                       => 'The given category constant "%s" could not be found.',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_IMPACT_OBJECT'                          => 'You have selected no impact object!',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_ATTRIBUTES'                             => 'You have selected no attributes!',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_JSON_RESPONSE'                          => 'The function "%s" did not answer with proper JSON Data, please check the i-doit LOG.',
    'LC__MODULE__ANALYTICS__NOTIFY__NO_OBJECTS_FOR_GIVEN_TYPE'                 => 'The given objecttype "%s" has no objects.',
    'LC__MODULE__ANALYTICS__EXCEPTION__NO_CLASS_FOUND'                         => 'The given class "%s" could not be found!',
    'LC__MODULE__ANALYTICS__EXCEPTION__NO_REPORT_FOUND'                        => 'The given report "%s" could not be found!',
    'LC__MODULE__ANALYTICS__EXCEPTION__FILTER_NAME_UNIQUE'                     => 'Attention! The filtername needs to be unique, please choose another title.',
];
